# WebRunner as automation framework for web testing

#### Features

* Selenium wrapper, include a manager to manage selenium instance
* Auto download needed webdriver

---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/cc97412a6f3e4c5592ce45dd7b9db946)](https://www.codacy.com/gh/JE-Chen/WebRunner/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/WebRunner&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://circleci.com/gh/JE-Chen/WebRunner/tree/main.svg?style=svg)](https://circleci.com/gh/JE-Chen/WebRunner/tree/main)

[![WebRunner GitHub Actions Dev](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml)

[![WebRunner GitHub Actions Stable](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/webrunner-dev/badge/?version=latest)](https://webrunner-dev.readthedocs.io/en/latest/?badge=latest)

---

## install

```
pip install je_web_runner
```

## Requires

```
python 3.7 or later
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir